UNIT uArtikel;

(* ******************************************************************** *)
(* K L A S S E : TArtikel                                               *)
(* -------------------------------------------------------------------- *)
(* Version     : 1.1                                                    *)
(* Autor       : J. Neumann, OSZ-Handel I, 10997 Berlin                 *)
(*                                                                      *)
(* Beschreibung: bildet das Objekt Artikel ab.                          *)
(*                                                                      *)
(* Compiler    : DELPHI 3.0                                             *)
(* Aenderung   : V. 1.1  25-OKT-00                                      *)
(* ******************************************************************** *)

INTERFACE
(* ========================== Export ================================== *)
USES  Classes;

type
   TArtikel = class
     private
      Nummer  : word;
      Bezeichnung: string[15];
      Preis : real;

      public
      constructor Create;                   virtual;
      procedure Init;                       virtual;
      procedure SetNummer(nr : word);       virtual;
      procedure SetBezeichnung (b : string);virtual;
      procedure SetPreis (pr : real);       virtual;
      function  istgroesser (nr:word): boolean; virtual;
      function  IstGleich (nr:word) : boolean;  virtual;
      function  GetNummer : word;           virtual;
      function  GetBezeichnung : string;    virtual;
      function  GetPreis : real;            virtual;

      procedure InDateiSchreiben (var Fs : TFilestream); virtual;
      procedure AusDateiLesen  (var Fs : TFilestream);   virtual;
   end;

(* -------------------- B e s c h r e i b u n g -------------------------

Bezugsklassen  : TClasses - import: TFilestream, read,write


Methoden
--------

Create
  Auftrag: Artikel erzeugen
  vorher : -
  nachher: ist vorhanden; alle Felder sind leer

Init
  Auftrag: Artikel Initialisieren
  vorher : Artikel ist vorhanden.
  nachher: alle Felder sind leer

Set...
  Auftrag: Attribut schreiben
  vorher : Artikel ist vorhanden.
  nachher: Attribut ist gesetzt

Get...
  Auftrag: Attribut aus dem Objekt lesen
  vorher : Artikel ist vorhanden.
  nachher: -

IstGleich (suchartikel : TArtikel) : boolean
  Anfrage: prfen, ob Artikel gleich suchartikel ist.
  vorher : Artikel ist initialisiert.
  nachher: IstGleich ist wahr, wenn beide Nummer bereinstimmen.

InDateiSchreiben (var fs : TFilestream)
  Auftrag: Attribute auf die Festplatte speichern
  vorher : fs ist geffnet
  nachher: Attribute sind an fs uebergeben


AusDateiLesen (var fs : TFilestream)
  Auftrag: Attribute von der Festplatte laden
  vorher : fs ist geffnet
  nachher: Attribute sind an Artikel uebergeben
----------------------------------------------------------------------- *)

IMPLEMENTATION
(* ==================================================================== *)

constructor TArtikel.Create;
begin
  Init;
end;


procedure TArtikel.Init;
(* -------------------------------------------------------------------- *)
begin
	Nummer   := 0;
	Bezeichnung := '';
	Preis   := 0;
end;


procedure TArtikel.SetNummer (nr : word);
(* -------------------------------------------------------------------- *)
begin
  Nummer := nr;
end;


procedure TArtikel.SetBezeichnung (b : string);
(* -------------------------------------------------------------------- *)
begin
  Bezeichnung := b;
end;


procedure TArtikel.SetPreis (pr : real);
(* -------------------------------------------------------------------- *)
begin
  Preis := pr;
end;


function TArtikel.GetNummer : word;
(* -------------------------------------------------------------------- *)
begin
  result := Nummer;
end;


function TArtikel.GetBezeichnung : string;
(* -------------------------------------------------------------------- *)
begin
  result := Bezeichnung;
end;


function TArtikel.GetPreis : real;
(* -------------------------------------------------------------------- *)
begin
  result := Preis;
end;


function TArtikel.IstGleich (nr:word) : boolean;
(* -------------------------------------------------------------------- *)
begin
  if nr = Nummer
  then result := true
  else result := false;
end;

function TArtikel.istgroesser (nr:word): boolean;
(* -------------------------------------------------------------------- *)
begin
  if nr>Nummer
  then result := true
  else result := false;
end;

procedure TArtikel.InDateiSchreiben (var Fs : TFilestream);
(* -------------------------------------------------------------------- *)
begin
  Fs.write( Nummer, sizeoF(Nummer));
  Fs.write( Bezeichnung, sizeoF(Bezeichnung));
  Fs.write( Preis, sizeoF(Preis));
end;


procedure TArtikel.AusDateiLesen (var Fs : TFilestream) ;
(* -------------------------------------------------------------------- *)
begin
  Fs.read( Nummer, sizeoF(Nummer));
  Fs.read( Bezeichnung, sizeoF(Bezeichnung));
  Fs.read( Preis, sizeoF(Preis));
end;


END.




