UNIT uBestellposition;

(* ******************************************************************** *)
(* K L A S S E : TBestellposition                                       *)
(* -------------------------------------------------------------------- *)
(* Version     : 1.0                                                    *)
(* Autor       : Christian & Alexander, 10997 Berlin                    *)
(*                                                                      *)
(* Beschreibung: bildet das Objekt Bestellposition ab.                  *)
(*                                                                      *)
(* Compiler    : DELPHI 4.0                                             *)
(* Aenderung   : V. 1.1  09-NOV-00                                      *)
(* ******************************************************************** *)

INTERFACE
(* ========================== Export ================================== *)
USES  Classes;

type
   TBestellposition = class (TObject)
               private
                KellnerNr  : byte ;  (* m,w*)
                TischNr    : byte;
                PlatzNr    : byte;
                ArtikelNr  : word;
                Bezahlt    : BOOLEAN;

               public
                constructor Create;
                procedure Init;
                procedure SetKellnerNr (k : byte);   virtual;
                procedure SetTischNr   (t : byte); virtual;
                procedure SetPlatzNr   (p : byte);   virtual;
                procedure SetArtikelNr (a : word); virtual;
                procedure SetBezahlt   (b : boolean); virtual;

                function GetBezahlt     : boolean; virtual;
                function GetKellnerNr   : byte;        virtual;
                function GetTischNr     : byte;    virtual;
                function GetPlatzNr     : byte;        virtual;
                function GetArtikelNr   : word; virtual;

                procedure InDateiSchreiben (var Fs : TFilestream);
                procedure AusDateiLesen  (var Fs : TFilestream);
                function IstGleich (suchbet : byte) : boolean; reintroduce; overload;
              end;

(* -------------------- B e s c h r e i b u n g -------------------------

Oberklasse     : TBestellung
Bezugsklassen  : TClasses - import: TFilestream, read,write


Methoden
--------

Create
  Auftrag: Bestellposition erzeugen
  vorher : -
  nachher: ist vorhanden; alle Felder sind leer

Init
  Auftrag: Bestellpositionen Initialisieren
  vorher : -
  nachher: alle Felder sind leer

Set...
  Auftrag: Attribut schreiben
  vorher : Bestellposition ist vorhanden.
  nachher: Attribut ist gesetzt

Get...
  Auftrag: Attribut aus dem Objekt lesen
  vorher : Bestellposition ist vorhanden.
  nachher: -

InDateiSchreiben (var fs : TFilestream)
  Auftrag: Attribute auf die Festplatte speichern
  vorher : fs ist geffnet
  nachher: Attribute sind an fs uebergeben


AusDateiLesen (var fs : TFilestream)
  Auftrag: Attribute von der Festplatte laden
  vorher : fs ist geffnet
  nachher: Attribute sind an Bestellung uebergeben

IstGleich (tnr, pnr : byte) : boolean
  Anfrage: prfen, ob Element mit tnr, pnr in der Liste ist.
  vorher : Bestellposition ist initialisiert.
  nachher: IstGleich ist wahr, wenn beide Tischnummer und Platznummer
bereinstimmen.

----------------------------------------------------------------------- *)

IMPLEMENTATION
(* ==================================================================== *)

constructor TBestellposition.Create;
(* -------------------------------------------------------------------- *)
begin
  inherited Create;
  Init;
end;


procedure TBestellposition.Init;
(* -------------------------------------------------------------------- *)
begin
	KellnerNr   := 0;
	TischNr     := 0;
	PlatzNr     := 0;
        ArtikelNr   := 0;
end;


procedure TBestellposition.SetKellnerNr (k : byte);
(* -------------------------------------------------------------------- *)
begin
  KellnerNr := k;
end;


procedure TBestellposition.SetTischNr (t : byte);
(* -------------------------------------------------------------------- *)
begin
  TischNr := t;
end;


procedure TBestellposition.SetPlatzNr (p : byte);
(* -------------------------------------------------------------------- *)
begin
  PlatzNr := p;
end;


procedure TBestellposition.SetArtikelNr (a : word);
(* ------------------------------------------------------------------- *)
begin
  ArtikelNr := a;
end;


procedure TBestellposition.SetBezahlt (b : boolean);
(*-------------------------------------------------------------------- *)
begin
 Bezahlt := b;
end;


function TBestellposition.GetKellnerNr : byte;
(* -------------------------------------------------------------------- *)
begin
  result := KellnerNr;
end;


function TBestellposition.GetTischNr : byte;
(* -------------------------------------------------------------------- *)
begin
  result := TischNr;
end;


function TBestellposition.GetPlatzNr : byte;
(* -------------------------------------------------------------------- *)
begin
  result := PlatzNr;
end;


function TBestellposition.GetArtikelNr : word;
(*--------------------------------------------------------------------- *)
begin
 result := ArtikelNr;
end;


function TBestellposition.GetBezahlt : boolean;
(*--------------------------------------------------------------------- *)
begin
  result := Bezahlt;
end;


procedure TBestellposition.InDateiSchreiben (var Fs : TFilestream);
(* -------------------------------------------------------------------- *)
begin
  Fs.write( KellnerNr, sizeoF(KellnerNr));
  Fs.write( TischNr, sizeoF(TischNr));
  Fs.write( PlatzNr, sizeoF(PlatzNr));
  Fs.write ( ArtikelNr, sizeoF(ArtikelNr));
end;


procedure TBestellposition.AusDateiLesen (var Fs : TFilestream) ;
(* -------------------------------------------------------------------- *)
begin
  Fs.read( KellnerNr, sizeoF(KellnerNr));
  Fs.read( TischNr, sizeoF(TischNr));
  Fs.read( PlatzNr, sizeoF(PlatzNr));
  Fs.read( ArtikelNr, sizeoF(ArtikelNr));
end;


function TBestellposition.IstGleich (suchbet : byte) : boolean;
(* -------------------------------------------------------------------- *)
begin
  if  suchbet = KellnerNr
  then result := true
  else result := false
end;

END.
