UNIT uBestellung;
(* ******************************************************************** *)
(*                                                                      *)
(* K L A S S E   : TBestellung                                          *)
(* -------------------------------------------------------------------- *)
(* Version       : 1.0                                                  *)
(* Autor         : Alexander & Christian, OSZ-Handel I, 10997 Berlin    *)
(*                                                                      *)
(* Aufgabe       : Statische Liste zur Verwaltung der Bestell-          *)
(*                 Objekte.                                             *)
(*                                                                      *)
(* Compiler      : Delphi 4.0                                           *)
(* Aenderung     : V. 1.0   - 16-NOV-00                                 *)
(* ******************************************************************** *)

INTERFACE
(* ==================================================================== *)
USES  Classes,
      Sysutils,
      uSListe,
      uBestellposition;


type
  TElement = TBestellposition;

  TBestellung  = class (TListe)
                 public
                  procedure Load (Dateiname : string); override;
                  procedure Store(Dateiname : string); override;
                  procedure Sort; virtual;

                  function  SearchElem (tnr,pnr : byte) : TElement; reintroduce;
                 end;

(*  ----------------- B e s c h r e i b u n g -------------------------

Oberklasse     : TListe
Bezugsklassen  : TBestellposition
                 Classes - import: TFilstream, read, write
                 Sysutils        : Fileexists
Methoden
--------
SearchElem (tnr, pnr : byte) : TElement;
  Anfrage: ob Element mit Tischnummer und Platznummer in der Liste
gefunden wurde
  vorher : -
  nachher: Gefundenes Element mit Tisch- und Platznummer werden
zurckgegeben. Wenn Liste leer ist oder  nicht gefunden wird EoList
zurckgegeben.


Load (dateiname : string);
  Auftrag: Liste aus externer Datei laden. Wenn keine Datei existiert, dann neue
           Datei mit der Laenge 0 anlegen.
  vorher : Die Liste ist initialisiert.
  nachher: Die Liste ist in den Arbeitsspeicher geladen. Datei ist geschlossen.


Store (dateiname : string);
  Auftrag: Liste in externe Datei speichern
  vorher : -
  nachher: Die Liste ist gespeichert. Ist die Liste leer, wird nichts
          gespeichert. Datei ist geschlossen.

Sort
Auftrag: lineare Sortieren druchsystematisches Vergleichen aller Elemente und Tauschen
mit dem nachfolgenden Element
Vorher: Liste ist initialisiert
Nacher: Liste ist nach Nummern sortiert

----------------------------------------------------------------------- *)


IMPLEMENTATION
(* ==================================================================== *)

function  TBestellung.SearchElem (tnr,pnr : byte) : TElement;
(* -------------------------------------------------------------------- *)
var gefunden : boolean;
    Elem     : TElement;

begin
  Result   := NIL;
  gefunden := false;
  First;

  while NOT (gefunden or Eolist) do
  begin
    Elem := GetElement;
    if Elem.IstGleich(tnr)
    then
      begin
        gefunden := true;
        Result := Elem;
      end
    else Next;
  end;
end;


procedure TBestellung.Load (Dateiname : string);
(* -------------------------------------------------------------------- *)
var
    Elem  : TElement;
    Fs    : TFilestream;
    i,
    Anzahl: integer;

begin

  Anzahl := 0 ;
  if NOT FileExists(Dateiname)
  then Fs := TFilestream.Create(Dateiname, fmCreate)
  else Fs := TFilestream.Create(Dateiname, fmOpenRead);

  if Fs.Size > 0
  then
    begin
      Fs.Read(Anzahl, SizeOf(Lilaenge));
      for i := 1 to Anzahl do
      begin
        elem := Telement.Create;
        Elem.AusDateiLesen(Fs);
        Append(Elem);
      end;
      First;
    end;
  Fs.Free;
end;


procedure TBestellung.Store(Dateiname : string);
(* -------------------------------------------------------------------- *)
var Elem  : TElement;
    Fs    : TFilestream;

begin
  DeleteFile(Dateiname);
  Fs := TFilestream.Create(Dateiname, fmCreate);

  if not IsEmpty
  then
  begin
    Fs.Write(Lilaenge, SizeOf(Lilaenge));
    First;
    while NOT EoList do
    begin
      Elem := GetElement;
      Elem.InDateiSchreiben (Fs);
      Next;
    end;
  end;
  Fs.Free;
end;

procedure Tauschen (var El1, El2 : TElement);
(* ------------------------------------  *)
var
   hilf : TElement;
begin
    hilf := El1;
    El1  := El2;
    El2  := hilf
end;

procedure TBestellung.Sort;
(* -------------------------------------------------------------------- *)
var
 durchlauf,
 i:integer;
 el1,
 el2      : Telement;
begin
 for durchlauf := 1 to (Lilaenge) do
 begin
   for i := 1 to (LiLaenge - 1) do
     begin
       el1:=Kollektion[i];
       el2:=Kollektion[i+1];
       if (el1.GetKellnerNr > el2.GetKellnerNr)
       then
       tauschen(el1,el2);
       Kollektion[i]:=el1;
       Kollektion[i+1]:=el2;
      end;
    end;
end;


END.
