UNIT uKellner;

(* ******************************************************************** *)
(*                                                                      *)
(* K L A S S E : TKellner                                               *)
(* -------------------------------------------------------------------- *)
(* Version     : 1.21                                                   *)
(* Autor       : J. Schneider, H. Kriesing OSZ-Handel I, 10997 Berlin   *)
(*                                                                      *)
(* Aufgabe     : bildet das Objekt Kellner ab.                          *)
(*                                                                      *)
(* Compiler    : DELPHI 4.0                                             *)
(* Aenderung   : V. 1.1  16-11-2000                                     *)
(*                                                                      *)
(* ******************************************************************** *)

INTERFACE
(* ========================== Export ================================== *)
USES Classes;

type
   TKellner = class (TObject)
     private
      Kellnername    : string[30];
      Kellnernummer  : byte;

      public

      constructor Create;                                     virtual;
      procedure   Init;                                       virtual;
      procedure   SetKellnername (k: string);                 virtual;
      procedure   SetKellnernummer (kn : byte);               virtual;

      function GetKellnername : string;                       virtual;
      function GetKellnernummer : byte;                       virtual;

      function IstGleich (suchpers : TKellner) : boolean; virtual;

      procedure InDateiSchreiben (var fs : TFilestream);      virtual;
      procedure AusDateiLesen    (var fs : TFilestream);      virtual;
   end; (* TKellner *)

(* -------------------- B e s c h r e i b u n g -------------------------

Oberklasse     : -
Bezugsklassen  : Classes import: TFilestream, read write



Methoden
--------

Create
  Auftrag: Kellner  erzeugen und Initialisieren
  vorher : -
  nachher: Kellner ist erzeugt,alle Datenfelder sind leer.

Init
  Auftrag: Kellner Initialisieren
  vorher : ist erzeugt
  nachher: alle Datenfelder sind leer.

Set...
  Auftrag: Attribut schreiben
  vorher : Kellner ist vorhanden.
  nachher: Attribut ist gesetzt

Get...
  Anfrage: Attribut aus dem Objekt lesen
  vorher : Kellner ist vorhanden.
  nachher: -

IstGleich (suchKellner : TKellner)  : boolean
  Anfrage: prfen, ob Kellner gleich gesuchte Kellner ist.
  vorher : Kellner ist vorhanden.
  nachher: IstGleich ist wahr, wenn SuchKellnerKellnername und Kellnername bereinstimmen.


InDateiSchreiben (var fs : TFilestream)
  Auftrag: Attribute auf die Festplatte speichern
  vorher : fs ist geffnet
  nachher: Attribute sind an fs uebergeben


AusDateiLesen (var fs : TFilestream)
  Auftrag: Attribute von der Festplatte laden
  vorher : fs ist geffnet
  nachher: Attribute sind an Kellner uebergeben
----------------------------------------------------------------------- *)

IMPLEMENTATION
(* ==================================================================== *)

constructor TKellner.Create;
(* -------------------------------------------------------------------- *)
begin
   inherited Create;
   Init;
end;

procedure TKellner.Init;
(* -------------------------------------------------------------------- *)
begin
  Kellnername       := '';
  Kellnernummer     :=  0;
end;

procedure TKellner.SetKellnername (k: string);
(* -------------------------------------------------------------------- *)
begin
  Kellnername := k;
end;


procedure TKellner.SetKellnernummer (kn: byte);
(* -------------------------------------------------------------------- *)
begin
  Kellnernummer := kn;
end;


function TKellner.GetKellnername : string;
(* -------------------------------------------------------------------- *)
begin
  result := Kellnername;
end;


function TKellner.GetKellnernummer : byte;
(* -------------------------------------------------------------------- *)
begin
  result := Kellnernummer;
end;


function TKellner.IstGleich (suchpers : TKellner) : boolean;
(* -------------------------------------------------------------------- *)
begin
  if suchpers.Kellnernummer = Kellnernummer
  then result := true
  else result := false;
end;


procedure TKellner.InDateiSchreiben (var Fs : TFileStream);
(* -------------------------------------------------------------------- *)
begin
  Fs.write(Kellnername, sizeof(Kellnername));
  Fs.write(Kellnernummer, sizeof(Kellnernummer));
end;


procedure TKellner.AusDateiLesen (var Fs : TFileStream) ;
(* -------------------------------------------------------------------- *)
begin
  Fs.read(Kellnername, sizeoF(Kellnername));
  Fs.read(Kellnernummer, sizeoF(Kellnernummer));
end;


END.
