unit uRechnung;
(* ******************************************************************** *)
(*                                                                      *)
(* K L A S S E : TRechnung                                              *)
(* -------------------------------------------------------------------- *)
(* Version : 1.0                                                        *)
(* Autor   : Bertram Ryba, Sven Skudler                                 *)
(*									                                                    *)
(* Aufgabe : Allgemeine statische Liste zur Verwaltung einer Rechnung, 	*)
(*           die entweder fr einen einzelnen Platz oder                *)
(*           fr mehrere Pltze gleichzeitig berechnet wird.            *)
(* 									                                                    *)
(* Compiler: Delphi 4.0							                                    *)
(* ******************************************************************** *)

interface
(* ==================================================================== *)
uses classes,Sysutils,
     uSListe,
     uBestellung,
     uSpeisekarte,
     uBestellposition,
     uArtikel;
type
TRechnung = class (Tobject)
     private
       Firma           	:string;
       Rechnungsnummer 	:integer;
       KellnerNr        :byte;
       TischNr          :byte;
       PlatzNr         	:byte;
       ArtikelPositionen:TSpeisekarte;
       RechngsPreisDM  	:real;
       RechngsPreisEU  	:real;
       MwStDM 		:real;
       MwStEU           :real;
     public
       constructor create;                              virtual;
       procedure   init;                                virtual;
       procedure   SetFirma (f: string);                virtual;
       procedure   SetRechnungsnummer (rn: integer);  	virtual;
       procedure   ZusammenStellen(best: TBestellung; spk : TSpeisekarte);
       procedure   AllesZusammen;
       procedure   Load (Dateiname :string);
       procedure   Store(Dateiname :string);
       procedure InDateiSchreiben (var Fs : TFilestream);
       procedure AusDateiLesen  (var Fs : TFilestream);

     function IstGleich (suchelem : TRechnung) : boolean; reintroduce; overload;
     function    GetArtikelPositionen	:TListe;	virtual;
     function    GetRechnungsnummer	:integer;	virtual;
     function    GetRechngsPreisDM    :real;          virtual;
     function    GetRechngsPreisEU    :real;          virtual;
     function    GetMwStDM            :real;          virtual;
     function    GetMwStEU            :real;          virtual;
end;

(* ----------------- B e s c h r e i b u n g -------------------------

Oberklasse    : TObject
Bezugsklassen :

Methoden

Create
  Auftrag: Person und Adresse erzeugen und Initialisieren
  vorher : -
  nachher: Person ist erzeugt, alle Datenfelder sind leer.

Init
  Auftrag: Person Initialisieren
  vorher : ist erzeugt
  nachher: alle Datenfelder sind leer.

ZusammenStellen
  Auftrag: alle Bestellungen eines Platzes oder eines Tisches sollen aus
Bestellung zusammengestellt werden.
  vorher : -
  nachher: alle Bestellungen sind in ArtikelPositionen eingetragen.

AllesZusammen
  Auftrag:  Alle Bestellungen aus  ArtikelPositionen werden addiert,
            Umsatzsteuer und Endbetrag errechnet.
  vorher : -
  nachher: RechngspreisDM, MwStDM,  MwStDM enthalten Betraege.

EinzelnBerechnen
  Auftrag: Die Preise der Bestellungen eines Platzes werden zusammengerechnet.
  vorher : -
  nachher: Die Rechnung ist fertig

Set...
  Auftrag: Attribut schreiben
  vorher : Person ist vorhanden.
  nachher: Attribut ist gesetzt
Get...
  Anfrage: Attribut aus dem Objekt lesen
  vorher : Objekt ist vorhanden.
  nachher: -

InDateiSchreiben (var fs : TFilestream)
  Auftrag: Attribute auf die Festplatte speichern
  vorher : fs ist geffnet
  nachher: Attribute sind an fs uebergeben

AusDateiLesen (var fs : TFilestream)
  Auftrag: Attribute von der Festplatte laden
  vorher : fs ist geffnet
  nachher: Attribute sind an Person uebergeben

GetArtikelPositionen
   Auftrag: soll die bestellungen eines oder mehrerer
   Gste in einer Liste zusammenfassen
   Vorher: bestellungen mssen vorhanden sein
   nachher: die Berechnungen werden mglich

GetRechnungsnummer
   Auftrag: soll in der rechnungsliste nach best. nummern suchen
   vorher:  die rechnungsliste muss initialisiert werden.
   nachher: eine best. rechnung wird angezeigt

-------------------------------------------------------------------------*)
implementation

constructor TRechnung.create ;
(* --------------------------------------------------------------------- *)
begin
   inherited Create;
   Artikelpositionen := TSpeisekarte.Create;
   Init;
end;

procedure TRechnung.Init;
(* --------------------------------------------------------------------- *)
begin
  Rechnungsnummer         := 0;
  Firma          := 'Pizza Ristorante Mama Mia';
  TischNr        := 0;
  PlatzNr        := 0;
  KellnerNr      := 0;
  RechngspreisDM := 0;
  MwStDM         := 0;
  ArtikelPositionen.Init;           
end;
(*-----------------------------------------------------------------------*)
procedure   TRechnung.SetFirma (f: string);
begin
   Firma := f;
end;
(*---------------------------------------------------------------------- *)
procedure   TRechnung.SetRechnungsnummer (rn: integer);
begin
    Rechnungsnummer := rn;
end;
(*---------------------------------------------------------------------- *)
procedure   TRechnung.ZusammenStellen(best: TBestellung; spk : TSpeisekarte);
var bpos : TBestellposition;
    nr: Word;
    Artikel : TArtikel;
begin
    best.First;
    while not best.EoList do
    begin
        bpos := best.Searchelem(TischNr, PlatzNr) ;
           begin
            nr := bpos.GetArtikelNr;
            Artikel := spk.SearchElement(nr);
            Artikelpositionen.Append(Artikel);
        end;
      best.Next;
    end;
end;

(*---------------------------------------------------------------------- *)
procedure   TRechnung.AllesZusammen;
var   Art : TArtikel;
begin
  RechngspreisDM := 0;
  MwStDM         := 0;
  ArtikelPositionen.First;
     While NOT ArtikelPositionen.Eolist do
        begin
          Art := artikelpositionen.GetElement;
          RechngsPreisDM := RechngsPreisDM + Art.GetPreis;
        end;
      Artikelpositionen.Next;

  if artikelpositionen.EoList
  then
     begin
       RechngsPreisEU := RechngsPreisDM / 1.955830;
       MwStDM         := (RechngsPreisDM  / 1.16)* 0.16;
       MwStEU         := MwStDM / 1.955830;
  end;
end;
(*---------------------------------------------------------------------- *)
procedure   TRechnung.Load (Dateiname :string);
begin

end;
(* -------------------------------------------------------------------- *)
procedure   TRechnung.Store(Dateiname :string);
begin

end;
(* -------------------------------------------------------------------- *)
procedure TRechnung.InDateiSchreiben (var Fs : TFilestream);
begin

end;
(* -------------------------------------------------------------------- *)
procedure TRechnung.AusDateiLesen (var Fs : TFilestream) ;
begin

end;
(*--------------------------------------------------------------------- *)
function Trechnung.IstGleich(suchElem : TRechnung) : boolean;
begin
  if suchelem.rechnungsnummer = Rechnungsnummer
  then result := true
  else result := false;
end;
(*--------------------------------------------------------------*)
function    TRechnung.GetArtikelPositionen	:TListe;
begin
   result := Artikelpositionen;
end;
(*--------------------------------------------------------------*)
function    TRechnung.GetRechnungsnummer	:integer;
begin
   result := Rechnungsnummer;
end;
(*--------------------------------------------------------------*)
function    TRechnung.GetRechngsPreisDM : real;
begin
   result := rechngsPreisDM;
end;
(*--------------------------------------------------------------*)
function    TRechnung.GetRechngsPreisEU : real;
begin
    result := rechngsPreisEU;
end;
(* -------------------------------------------------------------*)
function    TRechnung.GetMwStDM: real;
begin
   result :=MwStDM;
end;
(* -------------------------------------------------------------*)
function    TRechnung.GetMwStEU: real;
begin
   result :=MwStEU;
end;

end.

