UNIT uSListe;
(* ******************************************************************** *)
(*                                                                      *)
(* K L A S S E   : TListe - (Teil-)abstrakte Klasse                     *)
(* -------------------------------------------------------------------- *)
(* Version       : 2.01                                                 *)
(* Autor         : (c) S. Spolwig, OSZ-Handel I, 10997 Berlin           *)
(*                                                                      *)
(* Aufgabe       : Allgemeine statische Liste zur Verwaltung beliebiger *)
(*                 Objekte.                                             *)
(*                 Zum Bewegen in der Liste ist intern eine Listenmarke *)
(*                 mitgefuehrt, die die jeweils aktuelle Listenposition *)
(*                 bezeichnet. Alle Operationen werden auf der aktuellen*)
(*                 Position ausgefuehrt.                                *)
(*                 In abgeleiteten Klassen sollte der Elemententyp de-  *)
(*                 klariert und die abstrakten Methoden Load, Store und *)
(*                 SearchElement berschrieben werden.                  *)
(*                                                                      *)
(*                 (SLISTE entspricht SLISTEN in Turbo-Pascal.)         *)
(*                                                                      *)
(* Compiler      : Delphi 4.0                                           *)
(* Aenderung     : V. 1.0   - 20-AUG-97                                 *)
(*                    1.02  - 03-SEP-98   Load, Store                   *)
(*                    1.03  - 06-Okt-98   SearchElement                 *)
(*                    1.04  - 17-JUL-99   Init, IsFull, Append,         *)
(*                                        First,Last,Next,Prev neu spez.*)
(*                    2.0   - 21-OKT-99   abstr. Methoden: Load, Store  *)
(*                                        SearchElement                 *)
(*										2.01	- 13-OKT-00 	GetAktuellePos                *)
(* ******************************************************************** *)

INTERFACE
(* ==================================================================== *)
const
  MAXLAENGE = 1000;

type
  TListe  = class (TObject)
    protected
    Kollektion  : array [0..MAXLAENGE + 1] of Pointer;
    LiLaenge,                 // Anzahl der belegten Elemente
    AktuellePos : integer;    // auf aktivem Element oder EoList

    public
    constructor Create;  virtual;
    procedure Init;      virtual;
    procedure First;     virtual;
    procedure Next ;     virtual;
    procedure previous;  virtual;
    procedure Last ;     virtual;

    function  GetElement: pointer;           virtual;
    procedure PutElement (Elem : pointer);   virtual;
    procedure Append (Elem : pointer);       virtual;
    procedure Remove;                        virtual;
    procedure RemoveAll;                     virtual;
    function  GetLen  : integer ;            virtual;
    function  GetAktuellePos : integer;      virtual;
    function  EoList  : boolean;             virtual;
    function  IsFirst : boolean;             virtual;
    function  IsLast  : boolean;             virtual;
    function  IsEmpty : boolean;             virtual;
    function  IsFull  : boolean;             virtual;
    function  SearchElement (suchElem : pointer) : pointer; virtual; //abstrakt
    procedure Load (Dateiname : string);     virtual;  //abstrakt
    procedure Store(Dateiname : string);     virtual;  //abstrakt
  end;

(*  ----------------- B e s c h r e i b u n g -------------------------

Oberklasse     : TObject
Bezugsklassen  : -


Methoden
--------

Create
  Auftrag : Leere L. erzeugen
  vorher  : -
  nachher : L. ist erzeugt und initialisiert. Lilaenge ist Null, AktuellePos ist 0.

Init
  Auftrag : L. initial.
  vorher  : L. ist vorhanden
  nachher : Lilaenge ist Null, AktuellePos ist 0.


First
  Auftrag : Listenmarke an das 1. Element setzen
  vorher  : Die Liste ist initialisiert und nicht leer.
  nachher : Aktuelle Position ist 1. Wenn die Liste leer ist, geschieht nichts.


Next
  Auftrag : Die Listenmarke auf das naechste Position setzen.
  vorher  : Die Liste ist initialisert
  nachher : Die Marke steht auf der neuen aktuellen Position
            Wenn EoList erreicht ist, geschieht nichts.


Previous
  Auftrag : Die Listenmarke um eins zuruecksetzen
  vorher  : Die Liste ist nicht leer.
  nachher : Die Marke steht auf der neuen aktuellen Position.
            Wenn die aktuelle Position 1 war, geschieht nichts

Last
  Auftrag : Listenmarke auf das letzte Element der Liste setzen
  vorher  : Die Liste ist nicht leer.
  nachher : Letztes vorhandenes Element ist aktuelle Position


GetElement
  Anfrage : Zugriff auf das aktuelle Element zum Lesen
  vorher  : Die Liste ist nicht leer.
  nachher : GetElement liefert (einen Zeiger auf) das aktuelle Element.


PutElement
  Auftrag : Zugriff auf die aktuelle Position zum Schreiben
  vorher  : Die Liste ist initialisiert.
  nachher : Elem ist an aktuelle Position uebergeben


Append 
  Auftrag : Neues Element an das Ende der Liste anhaengen.
            Wenn die Liste leer war, ist das neue El. das erste.
  vorher  : Die Liste ist initialisiert
  nachher : Listenlaenge ist um eins erhoeht. Ist die Liste voll,
            geschieht nichts.

Remove
  Auftrag: Das aktuelle Element loeschen.
  vorher : Die Liste ist nicht leer.
  nachher: Das aktuelle Element ist aus der Liste entfernt. Die Listen-
           laenge ist um eins vermindert. AktuellePos ist 1 oder 0, wenn leer.

RemoveAll
  Auftrag: Alle Elemente aus der Liste entfernen
  vorher : -
  nachher: Die Liste ist leer. AktuellePosition ist 0.


EoList
  Anfrage: Pruefen, ob das Ende der Liste erreicht ist.
  vorher : Die Liste ist initialisiert.
  nachher: True, wenn die Listenmarke hinter dem letzten belegten Element steht.


IsFirst  : boolean;
  Anfrage: AktuellePos pruefen
  vorher : Die Liste ist initialisiert.
  nachher: True, wenn AktuellePOs = 1


IsLast   : boolean;
  Anfrage: AktuellePos pruefen
  vorher : Die Liste ist initialisiert.
  nachher: True, wenn AktuellePos auf letztem El. steht.


IsEmpty
  Anfrage: ob Liste leer ist
  vorher : Die Liste ist initialisiert.
  nachher: True, wenn die Liste leer ist.


IsFull
  Anfrage: ob Liste voll ist
  vorher : Die Liste ist initialisiert.
  nachher: True, wenn die Liste voll ist.


GetLen
  Anfrage: gibt Listenlaenge zurueck
  vorher : Liste ist initialisiert
  nachher: -

GetAktuellePos
  Anfrage: gibt Listenlaenge zurueck
  vorher : Liste ist initialisiert
  nachher: -


SearchElement   // abstr. Methode
  Auftrag: Liste nach dem bergebenen Element durchsuchen
  vorher : nicht definiert
  nachher: nicht definiert


Load            // abstr. Methode
  Auftrag: Liste aus externer Datei laden.
  vorher : nicht definiert
  nachher: nicht definiert.


Store           // abstr. Methode
  Auftrag: Liste in externe Datei speichern
  vorher : nicht definiert.
  nachher: nicht definiert.

----------------------------------------------------------------------- *)


IMPLEMENTATION
(* ==================================================================== *)

constructor TListe.Create;
(* -------------------------------------------------------------------- *)
begin
  inherited Create;
  Init;
end;


procedure TListe.Init;
(* -------------------------------------------------------------------- *)
var i : integer;
begin
  for i := 0 to MAXLAENGE +1 do
  begin
    Kollektion[i] := NIL;
  end;
  Lilaenge    := 0;
  AktuellePos := 0;
end;


procedure TListe.First;
(* -------------------------------------------------------------------- *)
begin
  If NOT IsEmpty
  then AktuellePos := 1;
end;


procedure TListe.Next;
(* -------------------------------------------------------------------- *)
Begin
  if NOT (EoList)
  then AktuellePos := AktuellePos + 1;
end;


procedure TListe.Previous;
(* -------------------------------------------------------------------- *)
begin
  if NOT (IsEmpty or IsFirst)
  then AktuellePos := AktuellePos - 1;
end;


procedure TListe.Last;
(* -------------------------------------------------------------------- *)
begin
  AktuellePos := Lilaenge ;
end;


function TListe.GetElement : pointer;
(* -------------------------------------------------------------------- *)
begin
  Result := Kollektion[AktuellePos];
end;


procedure TListe.PutElement (Elem : pointer);
(* -------------------------------------------------------------------- *)
begin
  Kollektion[AktuellePos] := Elem;
end;


procedure TListe.Append (Elem : pointer);
(* -------------------------------------------------------------------- *)
begin
  if NOT IsFull
  then
    begin
      if IsEmpty
      then AktuellePos := 1
        else
          begin
            Last;
            Next; 
          end;
      PutElement(Elem);
      inc (Lilaenge);
    end;
end;


procedure TListe.Remove;
(* -------------------------------------------------------------------- *)
var
  i    : Cardinal;

begin
  if NOT IsEmpty
  then
    begin
      for i := aktuellepos to lilaenge do
      begin
        Kollektion[i] := Kollektion[i+1];
      end;
      
      dec(LiLaenge);
      First;
    end;
end;  (* remove *)


procedure TListe.RemoveAll;
(* -------------------------------------------------------------------- *)
begin
  if NOT IsEmpty
  then Init;
end;  (* remove *)


function TListe.GetLen : integer ;
(* -------------------------------------------------------------------- *)
begin
  Result := Lilaenge;
end;


function  TListe.GetAktuellePos : integer;
(* -------------------------------------------------------------------- *)
begin
  Result := AktuellePos;
end;


function TListe.EoList : boolean;
(* -------------------------------------------------------------------- *)
begin
  if Kollektion[AktuellePos] = NIL
  then Result := true
  else Result := false;
end;


function TListe.IsFirst : boolean;
(* -------------------------------------------------------------------- *)
begin
  if AktuellePos = 1
  then Result := true
  else Result := false;
end;


function TListe.IsLast : boolean;
(* -------------------------------------------------------------------- *)
begin
  if AktuellePos = LiLaenge
  then Result := true
  else Result := false;
end;


function TListe.IsEmpty : boolean ;
(* -------------------------------------------------------------------- *)
begin
  Result := false;
  if LiLaenge = 0
  then Result := true;
end;


function TListe.IsFull : boolean ;
(* -------------------------------------------------------------------- *)
begin
  Result := false;
  if LiLaenge = MAXLAENGE
  then Result := true;
end;


function  TListe.SearchElement (suchElem : pointer) : pointer;
(* -------------------------------------------------------------------- *)
begin
  result := NIL;
end;


procedure TListe.Load (Dateiname : string);
(* -------------------------------------------------------------------- *)
begin
end;


procedure TListe.Store(Dateiname : string);
(* -------------------------------------------------------------------- *)
begin
end;

END.
