UNIT uKellnerliste;
(* ******************************************************************** *)
(*                                                                      *)
(* K L A S S E   : TKellnerliste                                        *)
(* -------------------------------------------------------------------- *)
(* Version       : 1.0                                                  *)
(* Autor         : J. Schneider, H. Kriesing, OSZ-Handel I, 10997 Berlin*)
(*                                                                      *)
(* Aufgabe       : Statische Liste zur Verwaltung der Kellneren-        *)
(*                 Objekte.                                             *)
(*                                                                      *)
(* Compiler      : Delphi 4.0                                           *)
(* Aenderung     : V. 1.0   16-11-2000                                  *)
(* ******************************************************************** *)

INTERFACE
(* ==================================================================== *)
USES  Classes,     dialogs,
      Sysutils,
      uSListe,
      uKellner;


type
  TElement = TKellner;

  TKellnerliste  = class (TListe)
    public
     function  Searchpers (suchpers : TKellner) : TElement; virtual;
     procedure Load (Dateiname : string); override;
     procedure Store(Dateiname : string); override;
     procedure Bubblesort3;
  end;
(*  ----------------- B e s c h r e i b u n g -------------------------

Oberklasse     : TListe
Bezugsklassen  : TKellner
                 Classes - import: TFilstream, read, write
                 Sysutils        : Fileexists
Methoden
--------
SearchElement (suchElem : TElement) : TElement;
  Anfrage: ob suchElem in der Liste gefunden wurde
  vorher : -
  nachher: Gefundenes Element wird zurckgegeben. Wenn Liste leer ist oder
           nicht gefunden wird EoList zurckgegeben.


Load (dateiname : string);
  Auftrag: Liste aus externer Datei laden. Wenn keine Datei existiert, dann neue
           Datei mit der Laenge 0 anlegen.
  vorher : Die Liste ist initialisiert.
  nachher: Die Liste ist in den Arbeitsspeicher geladen. Datei ist geschlossen.


Store (dateiname : string);
  Auftrag: Liste in externe Datei speichern
  vorher : -
  nachher: Die Liste ist gespeichert. Ist die Liste leer, wird nichts
          gespeichert. Datei ist geschlossen.

----------------------------------------------------------------------- *)


IMPLEMENTATION
(* ==================================================================== *)


function  TKellnerliste.Searchpers (suchpers : TKellner) : TElement;
(* -------------------------------------------------------------------- *)
var gefunden : boolean;
    pers  : TElement;

begin
  Result   := NIL;
  gefunden := false;
  First;

  while NOT (gefunden or Eolist) do
  begin
    pers:= GetElement;
    showmessage( suchpers.getkellnername);

    if pers.IstGleich(suchpers)
    then
      begin
        gefunden := true;
        showmessage('fef : ' + pers.getkellnername);
        Result := pers;
      end
    else Next;
  end;
end;


procedure TKellnerliste.Load (Dateiname : string);
(* -------------------------------------------------------------------- *)
var
    Elem  : TElement;
    Fs    : TFilestream;
    i,
    Anzahl: integer;

begin

 Anzahl := 0 ;
  if NOT FileExists(Dateiname)
  then Fs := TFilestream.Create(Dateiname, fmCreate)
  else Fs := TFilestream.Create(Dateiname, fmOpenRead);

  if Fs.Size > 0
  then
    begin
      Fs.Read(Anzahl, SizeOf(Lilaenge));
      for i := 1 to Anzahl do
      begin
        elem := Telement.Create;
        Elem.AusDateiLesen(Fs);
        Append(Elem);
      end;
      First;
    end;
  Fs.Free;
end;


procedure TKellnerliste.Store(Dateiname : string);
(* -------------------------------------------------------------------- *)
var Elem  : TElement;
    Fs    : TFilestream;

begin
  DeleteFile(Dateiname);
  Fs := TFilestream.Create(Dateiname, fmCreate);

  if not IsEmpty
  then
  begin
    Fs.Write(Lilaenge, SizeOf(Lilaenge));
    First;
    while NOT EoList do
    begin
      Elem := GetElement;
      Elem.InDateiSchreiben (Fs);
      Next;
    end;
  end;
  Fs.Free;
end;

procedure Tauschen (var El1, El2 : TElement);
(* ------------------------------------  *)
var
   hilf : TElement;
begin
    hilf := El1;
    El1  := El2;
    El2  := hilf
end;

procedure TKellnerListe.Bubblesort3;
(* ------------------------------------------------------------------ *)
(* Auftrag: lineares Sortieren durch Vergleichen und Vertauschen des  *)
(*          nachfolgenden Elements bis nicht mehr getauscht wird.     *)
(*          Endmarke rueckt vor und verkleinert Restfeld              *)
(* vorher : Kollektion ist initialisiert                              *)
(* nachher: Kollektion ist aufsteigend sortiert                       *)
(* ------------------------------------------------------------------ *)
var
  y,
  Endmarke : integer;
  Vergleiche,
  swaps     : longint;  // beim Sortieren
  el1,el2 : TElement;
begin
  Endmarke  := LiLaenge - 1 ;


    for y := 1 to endmarke do
    begin
       el1:= Kollektion[y];
       el2:= Kollektion[y+1];
      if (el1.GetKellnernummer > el2.GetKellnernummer)
       then
        begin
          Tauschen (el1, el2);
          Kollektion[y]:=el1;
          Kollektion[y+1]:=el2;
        end;
    end;
end;
END.
